@@ -1,5 +1,5 @@
 from landlordai.game.landlord import LandlordGame
-from landlordai.game.player import LearningPlayer_v1, RandomPlayer
+from landlordai.game.player import LearningPlayer, RandomPlayer
 from landlordai.sim.game_stats import GameStats
 from landlordai.sim.simulate import Simulator
 
@@ -7,17 +7,17 @@ import numpy as np
 from tqdm import tqdm
 
 def load_net(net):
-    return LearningPlayer_v1(name=net, net_dir='../models/' + net,
-                             use_montecarlo_random=False,
-                             mc_best_move_depth=4,
-                             epsilon=0,
-                             learning_rate=0.2)
+    return LearningPlayer(name=net, net_dir='../models/' + net,
+                          estimation_mode=LearningPlayer.CONSENSUS_Q,
+                          mc_best_move_depth=1,
+                          epsilon=0,
+                          learning_rate=0.2)
 
 if __name__ == "__main__":
     #players = [load_net('3_30_sim5_model8')] + [load_net('3_30_sim5_model14')] + [LearningPlayer_v1(name='random') for _ in range(1)]
     #players = [LearningPlayer_v1(name='random') for _ in range(3)]
     #players = [load_net('4_1_sim1_model5'), load_net('4_1_sim1_model0')] + [LearningPlayer_v1(name='random') for _ in range(1)]
-    players = [load_net('4_2_sim4_model7'), load_net('4_2_sim3_model0'), load_net('4_2_sim3_model5')]
+    players = [load_net('4_2_sim4_model0'), load_net('4_2_sim4_model10'), load_net('4_2_sim4_model9')]
 
 
     while True:
@@ -28,8 +28,8 @@ if __name__ == "__main__":
 
     print('\n')
     for i in range(3):
-        print(players[i].get_future_q())
-        print(players[i]._record_state_q)
+        print(np.array(players[i].get_future_q(), dtype=np.float16))
+        print(np.array(players[i]._record_state_q, dtype=np.float16))
         print('\n')
 
     print('')
